Summary:          Manage Linux IP sets
Name:             ipset
Version:          7.19
Release:          1%{?dist}
License:          GPLv2
URL:              http://ipset.netfilter.org/
Source0:          %{url}/%{name}-%{version}.tar.bz2
Source1:          ipset.service
Source2:          ipset.start-stop

BuildRequires:    make autoconf automake libtool
BuildRequires:    libtool libtool-ltdl-devel libmnl-devel
Requires:         %{name}-libs = %{version}-%{release}

%description
IP sets are a framework inside the Linux kernel since version 2.4.x, which can
be administered by the ipset utility. Depending on the type, currently an IP
set may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.
If you want to:
 - store multiple IP addresses or port numbers and match against the collection
   by iptables at one swoop;
 - dynamically update iptables rules against IP addresses or ports without
   performance penalty;
 - express complex IP address and ports based rulesets with one single iptables
   rule and benefit from the speed of IP sets
then ipset may be the proper tool for you.


%package libs
Summary:       Libraries of libipset

%description libs
Libraries of libipset.


%package devel
Summary:       Development package of libipset
Requires:      %{name}-libs = %{version}-%{release}
Requires:      kernel-headers

%description devel
This package provides libipset development headers and libraries.


%package service
Summary:          Ipset service package
BuildRequires:    systemd
Requires:         %{name} = %{version}-%{release}
Requires:         iptables-services
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
BuildArch:        noarch

%description service
This package provides the service of ipset.


%prep
%autosetup -p1


%build
./autogen.sh
%configure --disable-static --with-kmod=no
rm -rf kernel
# disable rpath to avoid hardcode specific library paths and also for safety 
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build


%install
%make_install
rm -f %{buildroot}%{_libdir}/*.la

install -D -m 644 %{SOURCE1} %{buildroot}/%{_unitdir}/ipset.service
install -D -m 755 %{SOURCE2} %{buildroot}%{_libexecdir}/%{name}/ipset.start-stop

mkdir -p %{buildroot}%{_sysconfdir}/%{name}


%post libs -p /sbin/ldconfig


%postun libs -p /sbin/ldconfig


%post service
%systemd_post ipset.service


%postun service
%systemd_postun_with_restart ipset.service


%files
%license COPYING
%doc ChangeLog
%doc %{_mandir}/man8/*.8.gz
%{_sbindir}/%{name}*


%files libs
%license COPYING
%doc %{_mandir}/man3/libipset.3.gz
%{_libdir}/libipset.so.13*


%files devel
%{_includedir}/libipset
%{_libdir}/libipset.so
%{_libdir}/pkgconfig/libipset.pc


%files service
%{_unitdir}/%{name}.service
%dir %{_libexecdir}/%{name}
%attr(0755,root,root) %{_libexecdir}/%{name}/%{name}.start-stop
%ghost %config(noreplace) %attr(0600,root,root) %{_sysconfdir}/%{name}


%changelog
* Wed Jan 17 2024 wynnfeng <wynnfeng@tencent.com> - 7.19-1
- upgrade to 7.19

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.17-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Aug 21 2023 wynnfeng <wynnfeng@tencent.com> - 7.17-1
- upgrade to 7.17

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.15-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.15-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jul 20 2022 doriscchao <doriscchao@tencent.com> - 7.15-1
- initial build,Version 7.15, Release 1

